pub struct BoundedWorkers<State> { /* private fields */ }Expand description
Each worker retains one state. All workers dequeue from the same bounded channel, so work is never stranded behind a busy worker’s private queue.
Implementations
Sourceimpl<State: Send + 'static> BoundedWorkers<State>
impl<State: Send + 'static> BoundedWorkers<State>
Sourcepub fn start(
states: Vec<State>,
capacity: NonZeroUsize,
name: &str,
) -> Result<Self>
pub fn start( states: Vec<State>, capacity: NonZeroUsize, name: &str, ) -> Result<Self>
Start all workers before returning a capability that can admit work.